@@ -29,11 +29,6 @@
 #' @param mdr_filename The filename of the mdr (e.g. "mdr_example_data.csv").
 #' @param logfile_dir Is the absolute path to the directory where the logfile
 #'   will be stored. If not path is provided the tempdir() will be used.
-#' @param parallel A boolean. If `TRUE`, initializing a `future::plan()`
-#'   for running the code (default: `FALSE`).
-#' @param ncores A integer. The number of cores to use. Caution: you would
-#'   probably like to choose a low number when operating on large datasets.
-#'   Default: 2.
 #' @param demo_usage A boolean. If `TRUE`, a box is shown on the dashboard with
 #'   further instructions on how to use / configure the tool.
 #'
@@ -51,8 +46,6 @@ launch_app <- function(port = 3838,
                                                 package = "DQAstats"),
                        mdr_filename = "mdr_example_data.csv",
                        logfile_dir = tempdir(),
-                       parallel = FALSE,
-                       ncores = 2,
                        demo_usage = FALSE) {
 
   DIZtools::assign_to_R_env(key = "utils_path",
@@ -67,14 +60,6 @@ launch_app <- function(port = 3838,
                             val = logfile_dir,
                             pos = 1L)
 
-  DIZtools::assign_to_R_env(key = "parallel",
-                            val = parallel,
-                            pos = 1L)
-
-  DIZtools::assign_to_R_env(key = "ncores",
-                            val = ncores,
-                            pos = 1L)
-
   DIZtools::assign_to_R_env(key = "demo_usage",
                             val = demo_usage,
                             pos = 1L)
